#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.2
visibility:           public
id:                   skylighting-format-blaze-html-0.1.2-498dvUB1B6qAV0F3QYq08O
key:                  skylighting-format-blaze-html-0.1.2-498dvUB1B6qAV0F3QYq08O
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  bd9878a15280c6a61862198d0441cc3d
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.2-498dvUB1B6qAV0F3QYq08O

depends:
    base-4.18.2.1 blaze-html-0.9.2.0-GzsXlvfrcqyCxImJscSKAz
    containers-0.6.7 skylighting-core-0.14.5-Jbtw2frZqYf4GvbGMhcn65
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

